import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import cdk8s._jsii
import cdk8s_plus_17._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@opencdk8s/cdk8s-mongo-sts",
    "0.0.10",
    __name__[0:-6],
    "cdk8s-mongo-sts@0.0.10.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
